/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * SPDX-License-Identifier: BSD-3-Clause
 * For full license text, see the LICENSE file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OperationOptions } from "retry";
import {
  SourceCodeGroupT,
  SourceCodeGroupSearchResultT,
  SourceCodeRedirectInfoT,
  SourceCodeSpecificationT,
  ErrorResponseT,
  MoneyT,
  SimpleSearchResultT,
  SearchRequestT,
  PaginatedSearchResultT,
  ClosedObjectT,
  OpenObjectT,
  NoPropertiesAllowedT,
  SpecifiedPropertiesAllowedT,
  MoneyMnemonicT,
  BoolFilterT,
  PaginatedSearchResultBaseT,
  MatchAllQueryT,
  FilteredQueryT,
  QueryFilterT,
  QueryT,
  TermQueryT,
  TermFilterT,
  TextQueryT,
  Range2FilterT,
  BoolQueryT,
  SimpleSearchResultBaseT,
  NestedQueryT,
  FilterT,
  SortT,
  RangeFilterT,
  SearchRequestBaseT
} from "./sourceCodeGroups.types";
/**
 * Instantiate a Client object with desired ClientConfig to perform operations
 * available in this API client.
 *
 * Note: When performing operations that require ShopperJWT authentication, an
 * Authorization header containing a JWT can be added to the headers field of the
 * ClientConfig object. The Client will use that Authorization header for all the
 * operations it is used to perform.
 */
declare class SourceCodeGroups extends BaseClient {
  constructor(config: ClientConfig);
  /**
   * Deletes the source code group by ID.
   *
   * If you would like to get a raw Response object use the other deleteSourceCodeGroup function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type void.
   */
  deleteSourceCodeGroup(options?: {
    parameters?: {
      organizationId?: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<void>;
  /**
   * Deletes the source code group by ID.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise.
   */
  deleteSourceCodeGroup<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : void>;
  /**
   * Action to retrieve source code group information.
   *
   * If you would like to get a raw Response object use the other getSourceCodeGroup function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   *
   * @returns A promise of type SourceCodeGroupT.
   */
  getSourceCodeGroup(options?: {
    parameters?: {
      organizationId?: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
  }): Promise<SourceCodeGroupT>;
  /**
   * Action to retrieve source code group information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupT otherwise.
   */
  getSourceCodeGroup<T extends boolean>(
    options?: {
      parameters?: {
        organizationId?: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : SourceCodeGroupT>;
  /**
   * Updates the source code group with the specified information.
   *
   * If you would like to get a raw Response object use the other updateSourceCodeGroup function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type SourceCodeGroupT.
   */
  updateSourceCodeGroup(options: {
    parameters?: {
      organizationId?: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SourceCodeGroupT;
  }): Promise<SourceCodeGroupT>;
  /**
   * Updates the source code group with the specified information.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupT otherwise.
   */
  updateSourceCodeGroup<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SourceCodeGroupT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : SourceCodeGroupT>;
  /**
   * Creates a source code group using the information provided.
   *
   * If you would like to get a raw Response object use the other createSourceCodeGroup function.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   *
   * @returns A promise of type SourceCodeGroupT.
   */
  createSourceCodeGroup(options: {
    parameters?: {
      organizationId?: string;
      id: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SourceCodeGroupT;
  }): Promise<SourceCodeGroupT>;
  /**
   * Creates a source code group using the information provided.
   *
   * @param options - An object containing the options for this method.
   * @param parameters - An object containing the parameters for this method.
   * @param organizationId -
   * @param id - The ID of the source code group to create.
   * @param siteId -
   * @param headers - An object literal of key value pairs of the headers to be
   * sent with this request.
   * @param body - The data to send as the request body.
   * @param rawResponse - Set to true to return entire Response object instead of DTO.
   *
   * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupT otherwise.
   */
  createSourceCodeGroup<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        id: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SourceCodeGroupT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : SourceCodeGroupT>;
  /**
    * Searches for source code groups.
 
The query attribute specifies a complex query that can be used to narrow down the search with the following searchable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | sourceCode | String |
  | startTime | DateTime |
  | endTime | DateTime |
  | creationDate | DateTime |
  | enabled | Boolean |
  | active | Boolean |
  
The sourceCode and active fields can only be used in Queries as conjunctions (using AND). If the field is used in a disjunction
(OR) an exception will be thrown.

The output of the query can also be sorted, with the following sortable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | enabled | Boolean |
  | creationDate | DateTime |

    *
    * If you would like to get a raw Response object use the other sourceCodeGroupsSearch function.
    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    *
    * @returns A promise of type SourceCodeGroupSearchResultT.
    */
  sourceCodeGroupsSearch(options: {
    parameters?: {
      organizationId?: string;
      siteId?: string;
    };
    retrySettings?: OperationOptions;
    headers?: {
      [key: string]: string;
    };
    body: SearchRequestT;
  }): Promise<SourceCodeGroupSearchResultT>;
  /**
    * Searches for source code groups.
 
The query attribute specifies a complex query that can be used to narrow down the search with the following searchable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | sourceCode | String |
  | startTime | DateTime |
  | endTime | DateTime |
  | creationDate | DateTime |
  | enabled | Boolean |
  | active | Boolean |
  
The sourceCode and active fields can only be used in Queries as conjunctions (using AND). If the field is used in a disjunction
(OR) an exception will be thrown.

The output of the query can also be sorted, with the following sortable attributes:
  
  | Attribute | Type |
  |-----------|--------|
  | id| String |
  | description | String |
  | enabled | Boolean |
  | creationDate | DateTime |

    *
    * @param options - An object containing the options for this method.
    * @param parameters - An object containing the parameters for this method.
    * @param organizationId -
    * @param siteId -
    * @param headers - An object literal of key value pairs of the headers to be
    * sent with this request.
    * @param body - The data to send as the request body.
    * @param rawResponse - Set to true to return entire Response object instead of DTO.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupSearchResultT otherwise.
    */
  sourceCodeGroupsSearch<T extends boolean>(
    options: {
      parameters?: {
        organizationId?: string;
        siteId?: string;
      };
      retrySettings?: OperationOptions;
      headers?: {
        [key: string]: string;
      };
      body: SearchRequestT;
    },
    rawResponse?: T
  ): Promise<T extends true ? Response : SourceCodeGroupSearchResultT>;
}
declare namespace SourceCodeGroups {
  type SourceCodeGroup = SourceCodeGroupT;
  type SourceCodeGroupSearchResult = SourceCodeGroupSearchResultT;
  type SourceCodeRedirectInfo = SourceCodeRedirectInfoT;
  type SourceCodeSpecification = SourceCodeSpecificationT;
  type ErrorResponse = ErrorResponseT;
  type Money = MoneyT;
  type SimpleSearchResult = SimpleSearchResultT;
  type SearchRequest = SearchRequestT;
  type PaginatedSearchResult = PaginatedSearchResultT;
  type ClosedObject = ClosedObjectT;
  type OpenObject = OpenObjectT;
  type NoPropertiesAllowed = NoPropertiesAllowedT;
  type SpecifiedPropertiesAllowed = SpecifiedPropertiesAllowedT;
  type MoneyMnemonic = MoneyMnemonicT;
  type BoolFilter = BoolFilterT;
  type PaginatedSearchResultBase = PaginatedSearchResultBaseT;
  type MatchAllQuery = MatchAllQueryT;
  type FilteredQuery = FilteredQueryT;
  type QueryFilter = QueryFilterT;
  type Query = QueryT;
  type TermQuery = TermQueryT;
  type TermFilter = TermFilterT;
  type TextQuery = TextQueryT;
  type Range2Filter = Range2FilterT;
  type BoolQuery = BoolQueryT;
  type SimpleSearchResultBase = SimpleSearchResultBaseT;
  type NestedQuery = NestedQueryT;
  type Filter = FilterT;
  type Sort = SortT;
  type RangeFilter = RangeFilterT;
  type SearchRequestBase = SearchRequestBaseT;
}
export = SourceCodeGroups;
